@@ -142,12 +142,12 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_lambda
-import aws_cdk.aws_sns
-import aws_cdk.aws_sqs
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_889c7272
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_48bffef9
 
 
-@jsii.implements(aws_cdk.aws_sns.ITopicSubscription)
+@jsii.implements(_aws_cdk_aws_sns_889c7272.ITopicSubscription)
 class EmailSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-sns-subscriptions.EmailSubscription",
@@ -171,8 +171,8 @@ class EmailSubscription(
         email_address: builtins.str,
         *,
         json: typing.Optional[builtins.bool] = None,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''
         :param email_address: -
@@ -181,7 +181,7 @@ class EmailSubscription(
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EmailSubscription.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__66bf6df28f3509479122a4a6cf116ede9475d591d0694d21af87f897f1901e0a)
             check_type(argname="argument email_address", value=email_address, expected_type=type_hints["email_address"])
         props = EmailSubscriptionProps(
             json=json, dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
@@ -192,19 +192,19 @@ class EmailSubscription(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _topic: aws_cdk.aws_sns.ITopic,
-    ) -> aws_cdk.aws_sns.TopicSubscriptionConfig:
+        _topic: _aws_cdk_aws_sns_889c7272.ITopic,
+    ) -> _aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig:
         '''Returns a configuration for an email address to subscribe to an SNS topic.
 
         :param _topic: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EmailSubscription.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__842fd663e00fc30c6d1498c868ae256fc997cb87c8c23c641205c4b3e7c9101a)
             check_type(argname="argument _topic", value=_topic, expected_type=type_hints["_topic"])
-        return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
+        return typing.cast(_aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
 
 
-@jsii.implements(aws_cdk.aws_sns.ITopicSubscription)
+@jsii.implements(_aws_cdk_aws_sns_889c7272.ITopicSubscription)
 class LambdaSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-sns-subscriptions.LambdaSubscription",
@@ -246,10 +246,10 @@ class LambdaSubscription(
 
     def __init__(
         self,
-        fn: aws_cdk.aws_lambda.IFunction,
+        fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''
         :param fn: -
@@ -257,7 +257,7 @@ class LambdaSubscription(
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaSubscription.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__83d259e3e187dba7bd835379d97fd66d68d22b95510aac2b80556503f0456897)
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         props = LambdaSubscriptionProps(
             dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
@@ -268,19 +268,19 @@ class LambdaSubscription(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        topic: aws_cdk.aws_sns.ITopic,
-    ) -> aws_cdk.aws_sns.TopicSubscriptionConfig:
+        topic: _aws_cdk_aws_sns_889c7272.ITopic,
+    ) -> _aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig:
         '''Returns a configuration for a Lambda function to subscribe to an SNS topic.
 
         :param topic: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaSubscription.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__9c75cb1cf97d7f154b95818c7e0d898885682028e63de0dfb7a4964a7e2cf901)
             check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
-        return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [topic]))
+        return typing.cast(_aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig, jsii.invoke(self, "bind", [topic]))
 
 
-@jsii.implements(aws_cdk.aws_sns.ITopicSubscription)
+@jsii.implements(_aws_cdk_aws_sns_889c7272.ITopicSubscription)
 class SmsSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-sns-subscriptions.SmsSubscription",
@@ -300,8 +300,8 @@ class SmsSubscription(
         self,
         phone_number: builtins.str,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''
         :param phone_number: -
@@ -309,7 +309,7 @@ class SmsSubscription(
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SmsSubscription.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e24075f8f517f3fa10950e05d0c1c001e5712cba1bc5a316333561dcfc5639d2)
             check_type(argname="argument phone_number", value=phone_number, expected_type=type_hints["phone_number"])
         props = SmsSubscriptionProps(
             dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
@@ -320,19 +320,19 @@ class SmsSubscription(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _topic: aws_cdk.aws_sns.ITopic,
-    ) -> aws_cdk.aws_sns.TopicSubscriptionConfig:
+        _topic: _aws_cdk_aws_sns_889c7272.ITopic,
+    ) -> _aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig:
         '''Returns a configuration used to subscribe to an SNS topic.
 
         :param _topic: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SmsSubscription.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__5e5f240130a5fe542ca1346c2899f4ea0de9179b289e1abee42fc204d155e4b3)
             check_type(argname="argument _topic", value=_topic, expected_type=type_hints["_topic"])
-        return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
+        return typing.cast(_aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
 
 
-@jsii.implements(aws_cdk.aws_sns.ITopicSubscription)
+@jsii.implements(_aws_cdk_aws_sns_889c7272.ITopicSubscription)
 class SqsSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-sns-subscriptions.SqsSubscription",
@@ -352,11 +352,11 @@ class SqsSubscription(
 
     def __init__(
         self,
-        queue: aws_cdk.aws_sqs.IQueue,
+        queue: _aws_cdk_aws_sqs_48bffef9.IQueue,
         *,
         raw_message_delivery: typing.Optional[builtins.bool] = None,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''
         :param queue: -
@@ -365,7 +365,7 @@ class SqsSubscription(
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsSubscription.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__bce12291b35c5fa7100c5a75ef998119e6b788a8e3f19a0c5fe47ceebb39cd6d)
             check_type(argname="argument queue", value=queue, expected_type=type_hints["queue"])
         props = SqsSubscriptionProps(
             raw_message_delivery=raw_message_delivery,
@@ -378,16 +378,16 @@ class SqsSubscription(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        topic: aws_cdk.aws_sns.ITopic,
-    ) -> aws_cdk.aws_sns.TopicSubscriptionConfig:
+        topic: _aws_cdk_aws_sns_889c7272.ITopic,
+    ) -> _aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig:
         '''Returns a configuration for an SQS queue to subscribe to an SNS topic.
 
         :param topic: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsSubscription.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__80a3f4950b19902f259b6d2ba12e9f27428af228aa6064c8c4bbc2832e11807b)
             check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
-        return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [topic]))
+        return typing.cast(_aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig, jsii.invoke(self, "bind", [topic]))
 
 
 @jsii.data_type(
@@ -402,8 +402,8 @@ class SubscriptionProps:
     def __init__(
         self,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''Options to subscribing to an SNS topic.
 
@@ -431,17 +431,17 @@ class SubscriptionProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SubscriptionProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__9f733132ec2f29cc503ba4b375f9c6092baf6d8b42858216cd2c120e487cb5e8)
             check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
             check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
             self._values["filter_policy"] = filter_policy
 
     @builtins.property
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.IQueue]:
+    def dead_letter_queue(self) -> typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue]:
         '''Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
@@ -449,18 +449,18 @@ class SubscriptionProps:
         :default: - No dead letter queue enabled.
         '''
         result = self._values.get("dead_letter_queue")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.IQueue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue], result)
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]]:
         '''The filter policy.
 
         :default: - all messages are delivered
         '''
         result = self._values.get("filter_policy")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -474,7 +474,7 @@ class SubscriptionProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_sns.ITopicSubscription)
+@jsii.implements(_aws_cdk_aws_sns_889c7272.ITopicSubscription)
 class UrlSubscription(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-sns-subscriptions.UrlSubscription",
@@ -497,10 +497,10 @@ class UrlSubscription(
         self,
         url: builtins.str,
         *,
-        protocol: typing.Optional[aws_cdk.aws_sns.SubscriptionProtocol] = None,
+        protocol: typing.Optional[_aws_cdk_aws_sns_889c7272.SubscriptionProtocol] = None,
         raw_message_delivery: typing.Optional[builtins.bool] = None,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''
         :param url: -
@@ -510,7 +510,7 @@ class UrlSubscription(
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(UrlSubscription.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e8cfd8a596d1b2d35304c1ca2ebccc875ae4c3d3df4749b2e576cf416f277a07)
             check_type(argname="argument url", value=url, expected_type=type_hints["url"])
         props = UrlSubscriptionProps(
             protocol=protocol,
@@ -524,16 +524,16 @@ class UrlSubscription(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _topic: aws_cdk.aws_sns.ITopic,
-    ) -> aws_cdk.aws_sns.TopicSubscriptionConfig:
+        _topic: _aws_cdk_aws_sns_889c7272.ITopic,
+    ) -> _aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig:
         '''Returns a configuration for a URL to subscribe to an SNS topic.
 
         :param _topic: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(UrlSubscription.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__f415e4ca3a8db6da2655810994e67ee8003f866eae535dd4e40cc8d697b6a842)
             check_type(argname="argument _topic", value=_topic, expected_type=type_hints["_topic"])
-        return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
+        return typing.cast(_aws_cdk_aws_sns_889c7272.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
 
 
 @jsii.data_type(
@@ -550,9 +550,9 @@ class UrlSubscriptionProps(SubscriptionProps):
     def __init__(
         self,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
-        protocol: typing.Optional[aws_cdk.aws_sns.SubscriptionProtocol] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+        protocol: typing.Optional[_aws_cdk_aws_sns_889c7272.SubscriptionProtocol] = None,
         raw_message_delivery: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Options for URL subscriptions.
@@ -585,12 +585,12 @@ class UrlSubscriptionProps(SubscriptionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(UrlSubscriptionProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f51a649a8dfc2e7a670860f5185bdfa6826e2eb15735e95342c5852f63c5965d)
             check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
             check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
             check_type(argname="argument protocol", value=protocol, expected_type=type_hints["protocol"])
             check_type(argname="argument raw_message_delivery", value=raw_message_delivery, expected_type=type_hints["raw_message_delivery"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -601,7 +601,7 @@ class UrlSubscriptionProps(SubscriptionProps):
             self._values["raw_message_delivery"] = raw_message_delivery
 
     @builtins.property
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.IQueue]:
+    def dead_letter_queue(self) -> typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue]:
         '''Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
@@ -609,27 +609,29 @@ class UrlSubscriptionProps(SubscriptionProps):
         :default: - No dead letter queue enabled.
         '''
         result = self._values.get("dead_letter_queue")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.IQueue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue], result)
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]]:
         '''The filter policy.
 
         :default: - all messages are delivered
         '''
         result = self._values.get("filter_policy")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]], result)
 
     @builtins.property
-    def protocol(self) -> typing.Optional[aws_cdk.aws_sns.SubscriptionProtocol]:
+    def protocol(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sns_889c7272.SubscriptionProtocol]:
         '''The subscription's protocol.
 
         :default: - Protocol is derived from url
         '''
         result = self._values.get("protocol")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.SubscriptionProtocol], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_889c7272.SubscriptionProtocol], result)
 
     @builtins.property
     def raw_message_delivery(self) -> typing.Optional[builtins.bool]:
@@ -667,8 +669,8 @@ class EmailSubscriptionProps(SubscriptionProps):
     def __init__(
         self,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
         json: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Options for email subscriptions.
@@ -699,11 +701,11 @@ class EmailSubscriptionProps(SubscriptionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EmailSubscriptionProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__800bf06002be22a53c168e41524e42eeb57e06da500371468479d127abea9b4a)
             check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
             check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
             check_type(argname="argument json", value=json, expected_type=type_hints["json"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -712,7 +714,7 @@ class EmailSubscriptionProps(SubscriptionProps):
             self._values["json"] = json
 
     @builtins.property
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.IQueue]:
+    def dead_letter_queue(self) -> typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue]:
         '''Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
@@ -720,18 +722,18 @@ class EmailSubscriptionProps(SubscriptionProps):
         :default: - No dead letter queue enabled.
         '''
         result = self._values.get("dead_letter_queue")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.IQueue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue], result)
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]]:
         '''The filter policy.
 
         :default: - all messages are delivered
         '''
         result = self._values.get("filter_policy")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]], result)
 
     @builtins.property
     def json(self) -> typing.Optional[builtins.bool]:
@@ -766,8 +768,8 @@ class LambdaSubscriptionProps(SubscriptionProps):
     def __init__(
         self,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''Properties for a Lambda subscription.
 
@@ -807,17 +809,17 @@ class LambdaSubscriptionProps(SubscriptionProps):
             ))
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaSubscriptionProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5e56dd01cd9e94b0dd3281370319ba556eebc5528f146f5f5fdd9eebfbe5ad95)
             check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
             check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
             self._values["filter_policy"] = filter_policy
 
     @builtins.property
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.IQueue]:
+    def dead_letter_queue(self) -> typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue]:
         '''Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
@@ -825,18 +827,18 @@ class LambdaSubscriptionProps(SubscriptionProps):
         :default: - No dead letter queue enabled.
         '''
         result = self._values.get("dead_letter_queue")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.IQueue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue], result)
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]]:
         '''The filter policy.
 
         :default: - all messages are delivered
         '''
         result = self._values.get("filter_policy")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -862,8 +864,8 @@ class SmsSubscriptionProps(SubscriptionProps):
     def __init__(
         self,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
     ) -> None:
         '''Options for SMS subscriptions.
 
@@ -891,17 +893,17 @@ class SmsSubscriptionProps(SubscriptionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SmsSubscriptionProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ce928566c2cb5ee2c01d9b46b709b7a55136424627b6731558e46d63c6c9f8fa)
             check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
             check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
             self._values["filter_policy"] = filter_policy
 
     @builtins.property
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.IQueue]:
+    def dead_letter_queue(self) -> typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue]:
         '''Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
@@ -909,18 +911,18 @@ class SmsSubscriptionProps(SubscriptionProps):
         :default: - No dead letter queue enabled.
         '''
         result = self._values.get("dead_letter_queue")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.IQueue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue], result)
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]]:
         '''The filter policy.
 
         :default: - all messages are delivered
         '''
         result = self._values.get("filter_policy")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -947,8 +949,8 @@ class SqsSubscriptionProps(SubscriptionProps):
     def __init__(
         self,
         *,
-        dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
-        filter_policy: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]] = None,
+        dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
         raw_message_delivery: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Properties for an SQS subscription.
@@ -979,11 +981,11 @@ class SqsSubscriptionProps(SubscriptionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsSubscriptionProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__dfcc271364229be4712c2a7d415b7b4ef6b058b465f7bfbed4f5aa36e5e98992)
             check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
             check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
             check_type(argname="argument raw_message_delivery", value=raw_message_delivery, expected_type=type_hints["raw_message_delivery"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -992,7 +994,7 @@ class SqsSubscriptionProps(SubscriptionProps):
             self._values["raw_message_delivery"] = raw_message_delivery
 
     @builtins.property
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.IQueue]:
+    def dead_letter_queue(self) -> typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue]:
         '''Queue to be used as dead letter queue.
 
         If not passed no dead letter queue is enabled.
@@ -1000,18 +1002,18 @@ class SqsSubscriptionProps(SubscriptionProps):
         :default: - No dead letter queue enabled.
         '''
         result = self._values.get("dead_letter_queue")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.IQueue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue], result)
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]]:
         '''The filter policy.
 
         :default: - all messages are delivered
         '''
         result = self._values.get("filter_policy")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_sns.SubscriptionFilter]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]], result)
 
     @builtins.property
     def raw_message_delivery(self) -> typing.Optional[builtins.bool]:
@@ -1051,3 +1053,134 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__66bf6df28f3509479122a4a6cf116ede9475d591d0694d21af87f897f1901e0a(
+    email_address: builtins.str,
+    *,
+    json: typing.Optional[builtins.bool] = None,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__842fd663e00fc30c6d1498c868ae256fc997cb87c8c23c641205c4b3e7c9101a(
+    _topic: _aws_cdk_aws_sns_889c7272.ITopic,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__83d259e3e187dba7bd835379d97fd66d68d22b95510aac2b80556503f0456897(
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9c75cb1cf97d7f154b95818c7e0d898885682028e63de0dfb7a4964a7e2cf901(
+    topic: _aws_cdk_aws_sns_889c7272.ITopic,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e24075f8f517f3fa10950e05d0c1c001e5712cba1bc5a316333561dcfc5639d2(
+    phone_number: builtins.str,
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5e5f240130a5fe542ca1346c2899f4ea0de9179b289e1abee42fc204d155e4b3(
+    _topic: _aws_cdk_aws_sns_889c7272.ITopic,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bce12291b35c5fa7100c5a75ef998119e6b788a8e3f19a0c5fe47ceebb39cd6d(
+    queue: _aws_cdk_aws_sqs_48bffef9.IQueue,
+    *,
+    raw_message_delivery: typing.Optional[builtins.bool] = None,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__80a3f4950b19902f259b6d2ba12e9f27428af228aa6064c8c4bbc2832e11807b(
+    topic: _aws_cdk_aws_sns_889c7272.ITopic,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9f733132ec2f29cc503ba4b375f9c6092baf6d8b42858216cd2c120e487cb5e8(
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e8cfd8a596d1b2d35304c1ca2ebccc875ae4c3d3df4749b2e576cf416f277a07(
+    url: builtins.str,
+    *,
+    protocol: typing.Optional[_aws_cdk_aws_sns_889c7272.SubscriptionProtocol] = None,
+    raw_message_delivery: typing.Optional[builtins.bool] = None,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f415e4ca3a8db6da2655810994e67ee8003f866eae535dd4e40cc8d697b6a842(
+    _topic: _aws_cdk_aws_sns_889c7272.ITopic,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f51a649a8dfc2e7a670860f5185bdfa6826e2eb15735e95342c5852f63c5965d(
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+    protocol: typing.Optional[_aws_cdk_aws_sns_889c7272.SubscriptionProtocol] = None,
+    raw_message_delivery: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__800bf06002be22a53c168e41524e42eeb57e06da500371468479d127abea9b4a(
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+    json: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5e56dd01cd9e94b0dd3281370319ba556eebc5528f146f5f5fdd9eebfbe5ad95(
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ce928566c2cb5ee2c01d9b46b709b7a55136424627b6731558e46d63c6c9f8fa(
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dfcc271364229be4712c2a7d415b7b4ef6b058b465f7bfbed4f5aa36e5e98992(
+    *,
+    dead_letter_queue: typing.Optional[_aws_cdk_aws_sqs_48bffef9.IQueue] = None,
+    filter_policy: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_sns_889c7272.SubscriptionFilter]] = None,
+    raw_message_delivery: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
